==> side_menu_v3.6.0.tar.gz: side_menu/l10n/es.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Menú personalizado",
    "Enable the custom menu": "Habilitar el menú personalizado",
    "No": "No",
    "Yes": "Sí",
    "Menu": "Menú",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Usa la combinación de teclas <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> para activar y desactivar el menú lateral. Use <span class=\"keyboard-key\">tab<\/span> para navegar.",
    "Top menu": "Menu principal",
    "Apps that not must be moved in the side menu": "Aplicaciones que no se deben mover al menú lateral",
    "If there is no selection then the global configuration is applied.": "Si no hay selección, se aplica la configuración global.",
    "Experimental": "En pruebas",
    "Save": "Guardar",
    "You like this app and you want to support me?": "¿Te gusta esta aplicación y quieres apoyarme?",
    "Buy me a coffee ☕": "Cómprame un café ☕",
    "Hidden": "Oculto",
    "Small": "Pequeño",
    "Normal": "Normal",
    "Big": "Grande",
    "Hidden icon": "Ocultar Icono",
    "Small icon": "Icono pequeño",
    "Normal icon": "Icono normal",
    "Big icon": "Icono grande",
    "Hidden text": "Texto oculto",
    "Small text": "Texto pequeño",
    "Normal text": "Texto normal",
    "Big text": "Texto grande",
    "Colors": "Colores",
    "Background color": "Color de fondo",
    "Background color of current app": "Color de fondo de la aplicación actual",
    "Text color": "Color del texto",
    "Loader": "Cargador",
    "Icon": "Icono",
    "Same color": "El mismo color",
    "Opposite color": "Color opuesto",
    "Transparent": "Transparente",
    "Opaque": "Opaco",
    "Opener": "Abrir",
    "Default": "Por defecto",
    "Default (dark)": "Por defecto (oscuro)",
    "Hamburger": "Hamburguesa",
    "Hamburger (dark)": "Hamburger (negro)",
    "Hamburger 2": "Hamburguesa 2",
    "Hamburger 2 (dark)": "Hamburger 2 (negro)",
    "Before the logo": "Antes del logotipo",
    "After the logo": "Después del logotipo",
    "Position": "Posición",
    "Show only the opener (hidden logo)": "Mostrar solo abrir (ocultar logotipo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "No mostrar el menú lateral y el abridor si no hay aplicación (por ejemplo: páginas públicas).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Abra el menú cuando el ratón esté sobre el icono (se desactiva automáticamente en las pantallas táctiles)",
    "Display the big menu": "Mostrar el menú grande",
    "Display the logo": "Mostrar el logotipo",
    "Icons and texts": "Iconos y textos",
    "Loader enabled": "Cargador activado",
    "Tips": "Consejos",
    "Always displayed": "Siempre se muestra",
    "This is the automatic behavior when the menu is always displayed.": "Este es el comportamiento automático cuando aún se muestra el menú.",
    "Not compatible with touch screens.": "No es compatible con las pantallas táctiles.",
    "Big menu": "Menú grande",
    "Live preview": "Previsualización en directo",
    "Open apps in new tab": "Abrir las aplicaciones en una nueva pestaña",
    "Use the global setting": "Utilizar la configuración global",
    "Use my selection": "Utilizar mi selección",
    "Show and hide the list of applications": "Mostrar y ocultar la lista de aplicaciones",
    "Use the avatar instead of the logo": "Utilizar un avatar en lugar de un logotipo",
    "You do not have permission to change the settings.": "No tienes permiso para cambiar la configuración.",
    "Force this configuration to users": "Forzar esta configuración a todos los usuarios",
    "Export the configuration": "Exportar la configuración",
    "Purge the cache": "Vaciar la caché",
    "Show the link to settings": "Mostrar un enlace a la configuración",
    "The menu is enabled by default for users": "El menú está activado por defecto para los usuarios",
    "Except when the configuration is forced.": "Excepto cuando la configuración es forzada.",
    "Apps that should not be displayed in the menu": "Aplicaciones que no deben aparecer en el menú",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Esta función sólo es compatible con la pantalla del <code>menú grande<\/code>.",
    "The logo is a link to the default app": "El logotipo es un enlace a la aplicación por defecto",
    "Others": "Otros",
    "Categories": "Categorías",
    "Customize sorting": "Personalizar la clasificación",
    "Order by": "Ordenar por",
    "Name": "Nombre",
    "Customed": "Personalizado",
    "Show and hide the list of categories": "Mostrar y ocultar la lista de categorías",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Estos parámetros se utilizan cuando el tema oscuro o el tema oscuro de Breeze están activados.",
    "Dark mode colors": "Colores del modo oscuro",
    "With categories": "Con categorías",
    "Custom categories": "Categorías personalizadas",
    "Customize application categories": "Personalizar las categorías de las aplicaciones",
    "Reset to default": "Restablecer los valores por defecto",
    "Applications": "Aplicaciones",
    "Applications kept in the top menu": "Aplicaciones guardadas en el menú superior",
    "Applications kept in the top menu but also shown in side menu": "Las aplicaciones se mantienen en el menú superior pero también se muestran en el menú lateral",
    "These applications must be selected in the previous option.": "Estas aplicaciones deben ser seleccionadas en las opciones anteriores.",
    "Hide labels on mouse over": "Ocultar las etiquetas al pasar el ratón"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v3.11.5.tar.gz: side_menu/l10n/es.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Menú personalizado",
    "Enable the custom menu": "Habilitar el menú personalizado",
    "No": "No",
    "Yes": "Sí",
    "Menu": "Menú",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Usa la combinación de teclas <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> para activar y desactivar el menú lateral. Use <span class=\"keyboard-key\">tab<\/span> para navegar.",
    "Top menu": "Menu principal",
    "Apps that not must be moved in the side menu": "Aplicaciones que no se deben mover al menú lateral",
    "If there is no selection then the global configuration is applied.": "Si no hay selección, se aplica la configuración global.",
    "Experimental": "En pruebas",
    "Save": "Guardar",
    "You like this app and you want to support me?": "¿Te gusta esta aplicación y quieres apoyarme?",
    "Buy me a coffee ☕": "Cómprame un café ☕",
    "Hidden": "Oculto",
    "Small": "Pequeño",
    "Normal": "Normal",
    "Big": "Grande",
    "Hidden icon": "Ocultar Icono",
    "Small icon": "Icono pequeño",
    "Normal icon": "Icono normal",
    "Big icon": "Icono grande",
    "Hidden text": "Texto oculto",
    "Small text": "Texto pequeño",
    "Normal text": "Texto normal",
    "Big text": "Texto grande",
    "Colors": "Colores",
    "Background color": "Color de fondo",
    "Background color of current app": "Color de fondo de la aplicación actual",
    "Text color": "Color del texto",
    "Loader": "Cargador",
    "Icon": "Icono",
    "Same color": "El mismo color",
    "Opposite color": "Color opuesto",
    "Transparent": "Transparente",
    "Opaque": "Opaco",
    "Opener": "Abrir",
    "Default": "Por defecto",
    "Default (dark)": "Por defecto (oscuro)",
    "Hamburger": "Hamburguesa",
    "Hamburger (dark)": "Hamburger (negro)",
    "Hamburger 2": "Hamburguesa 2",
    "Hamburger 2 (dark)": "Hamburger 2 (negro)",
    "Before the logo": "Antes del logotipo",
    "After the logo": "Después del logotipo",
    "Position": "Posición",
    "Show only the opener (hidden logo)": "Mostrar solo abrir (ocultar logotipo)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "No mostrar el menú lateral y el abridor si no hay aplicación (por ejemplo: páginas públicas).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Abra el menú cuando el ratón esté sobre el icono (se desactiva automáticamente en las pantallas táctiles)",
    "Display the big menu": "Mostrar el menú grande",
    "Display the logo": "Mostrar el logotipo",
    "Icons and texts": "Iconos y textos",
    "Loader enabled": "Cargador activado",
    "Tips": "Consejos",
    "Always displayed": "Siempre se muestra",
    "This is the automatic behavior when the menu is always displayed.": "Este es el comportamiento automático cuando aún se muestra el menú.",
    "Not compatible with touch screens.": "No es compatible con las pantallas táctiles.",
    "Big menu": "Menú grande",
    "Live preview": "Previsualización en directo",
    "Open apps in new tab": "Abrir las aplicaciones en una nueva pestaña",
    "Use the global setting": "Utilizar la configuración global",
    "Use my selection": "Utilizar mi selección",
    "Show and hide the list of applications": "Mostrar y ocultar la lista de aplicaciones",
    "Use the avatar instead of the logo": "Utilizar un avatar en lugar de un logotipo",
    "You do not have permission to change the settings.": "No tienes permiso para cambiar la configuración.",
    "Force this configuration to users": "Forzar esta configuración a todos los usuarios",
    "Export the configuration": "Exportar la configuración",
    "Purge the cache": "Vaciar la caché",
    "Show the link to settings": "Mostrar un enlace a la configuración",
    "The menu is enabled by default for users": "El menú está activado por defecto para los usuarios",
    "Except when the configuration is forced.": "Excepto cuando la configuración es forzada.",
    "Apps that should not be displayed in the menu": "Aplicaciones que no deben aparecer en el menú",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Esta función sólo es compatible con la pantalla del <code>menú grande<\/code>.",
    "The logo is a link to the default app": "El logotipo es un enlace a la aplicación por defecto",
    "Others": "Otros",
    "Categories": "Categorías",
    "Customize sorting": "Personalizar la clasificación",
    "Order by": "Ordenar por",
    "Name": "Nombre",
    "Customed": "Personalizado",
    "Show and hide the list of categories": "Mostrar y ocultar la lista de categorías",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Estos parámetros se utilizan cuando el tema oscuro o el tema oscuro de Breeze están activados.",
    "Dark mode colors": "Colores del modo oscuro",
    "With categories": "Con categorías",
    "Custom categories": "Categorías personalizadas",
    "Customize application categories": "Personalizar las categorías de las aplicaciones",
    "Reset to default": "Restablecer los valores por defecto",
    "Applications": "Aplicaciones",
    "Applications kept in the top menu": "Aplicaciones guardadas en el menú superior",
    "Applications kept in the top menu but also shown in side menu": "Las aplicaciones se mantienen en el menú superior pero también se muestran en el menú lateral",
    "These applications must be selected in the previous option.": "Estas aplicaciones deben ser seleccionadas en las opciones anteriores.",
    "Hide labels on mouse over": "Ocultar las etiquetas al pasar el ratón",
    "Except the hovered app": "Except the hovered app",
    "Search": "Search"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
